Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(337)

Unified Diff: editor/tools/plugins/com.google.dart.tools.debug.ui/src/com/google/dart/tools/debug/ui/internal/browser/BrowserMainTab.java

Issue 9178032: Rename and move refactorings in the launch code. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: editor/tools/plugins/com.google.dart.tools.debug.ui/src/com/google/dart/tools/debug/ui/internal/browser/BrowserMainTab.java
===================================================================
--- editor/tools/plugins/com.google.dart.tools.debug.ui/src/com/google/dart/tools/debug/ui/internal/browser/BrowserMainTab.java (revision 3372)
+++ editor/tools/plugins/com.google.dart.tools.debug.ui/src/com/google/dart/tools/debug/ui/internal/browser/BrowserMainTab.java (working copy)
@@ -13,7 +13,7 @@
* License for the specific language governing permissions and limitations under
* the License.
*/
-package com.google.dart.tools.debug.ui.internal.client;
+package com.google.dart.tools.debug.ui.internal.browser;
import com.google.dart.tools.debug.ui.internal.DartDebugUIPlugin;
import com.google.dart.tools.debug.ui.internal.DartUtil;
@@ -35,16 +35,16 @@
/**
* Main Dart Launch/Debug configuration tab
*/
-public class MainDartJsLaunchConfigurationTab extends AbstractLaunchConfigurationTab {
+public class BrowserMainTab extends AbstractLaunchConfigurationTab {
- private MainDartJsLaunchConfigurationPanel panel;
+ private BrowserLaunchConfigurationPanel panel;
private int initialLaunchType;
private String initialResPath;
private boolean initialExternal;
@Override
public void createControl(Composite parent) {
- panel = new MainDartJsLaunchConfigurationPanel(parent, SWT.NONE, this);
+ panel = new BrowserLaunchConfigurationPanel(parent, SWT.NONE, this);
setControl(panel);
// TODO (danrubel) implement help
@@ -138,7 +138,7 @@
}
/**
* Called by the {@link MainDartJsLaunchConfigurationPanel} when the user has changed the panel
* content.
*/
void panelChanged() {
@@ -138,7 +138,7 @@
}
/**
- * Called by the {@link MainDartJsLaunchConfigurationPanel} when the user has changed the panel
+ * Called by the {@link BrowserLaunchConfigurationPanel} when the user has changed the panel
* content.
*/

Powered by Google App Engine
This is Rietveld 408576698